@@ -18,12 +18,13 @@
 
 #define MAJOR 2
 #define MINOR 12
-#define PATCH 0
+#define PATCH 3
 
 extern int SLSMainConnectionID(void);
 extern int RunApplicationEventLoop(void);
 
 int g_connection;
+CFTypeRef g_transaction;
 
 struct bar_manager g_bar_manager;
 struct event_loop g_event_loop;
@@ -72,9 +73,13 @@ static int client_send_message(int argc, char **argv) {
     free(message);
     if (!rsp) return EXIT_SUCCESS;
 
-    printf("%s", rsp);
+    if (strlen(rsp) > 2 && rsp[1] == '!') {
+      fprintf(stderr, "%s", rsp);
+      return EXIT_FAILURE;
+    } else {
+      fprintf(stdout, "%s", rsp);
+    }
 
-    if (strlen(rsp) > 2 && rsp[1] == '!') return EXIT_FAILURE;
     return EXIT_SUCCESS;
 }
 
@@ -146,7 +151,11 @@ static inline void init_misc_settings(void) {
 
     snprintf(g_lock_file, sizeof(g_lock_file), LCFILE_PATH_FMT, user);
 
-    NSApplicationLoad();
+    if (__builtin_available(macOS 13.0, *)) {
+    } else {
+      NSApplicationLoad();
+    }
+
     signal(SIGCHLD, SIG_IGN);
     signal(SIGPIPE, SIG_IGN);
     CGSetLocalEventsSuppressionInterval(0.0f);
