@@ -1,12 +1,15 @@
 #pragma once
 #include "misc/helpers.h"
 
-// CFTypeRef SLSTransactionCreate(int cid);
-// extern CGError SLSTransactionSetWindowShape(CFTypeRef transaction, uint32_t wid, float x_offset, float y_offset, CFTypeRef region);
-// extern CGError SLSTransactionOrderWindow(CFTypeRef transaction, uint32_t wid, int mode, uint32_t relativeToWID);
-// extern CGError SLSTransactionSetWindowLevel(CFTypeRef transaction, uint32_t wid, int level);
-// extern CGError SLSTransactionCommitUsingMethod(CFTypeRef transaction, uint32_t method);
-// extern CGError SLSTransactionCommit(CFTypeRef transaction, uint32_t async);
+CFTypeRef SLSTransactionCreate(int cid);
+extern CGError SLSTransactionOrderWindow(CFTypeRef transaction, uint32_t wid, int mode, uint32_t relativeToWID);
+extern CGError SLSTransactionSetWindowLevel(CFTypeRef transaction, uint32_t wid, int level);
+extern CGError SLSTransactionSetWindowShape(CFTypeRef transaction, uint32_t wid, float x_offset, float y_offset, CFTypeRef shape);
+extern CGError SLSTransactionMoveWindowWithGroup(CFTypeRef transaction, uint32_t wid, CGPoint point);
+// extern CGError SLSTransactionAddWindowToWindowOrderingGroup(CFTypeRef transaction, uint32_t parent_wid, uint32_t child_wid, int order);
+// extern CGError SLSTransactionClearWindowOrderingGroup(CFTypeRef transaction, uint32_t wid);
+extern CGError SLSTransactionCommitUsingMethod(CFTypeRef transaction, uint32_t method);
+extern CGError SLSTransactionCommit(CFTypeRef transaction, uint32_t async);
 
 extern CGError SLSDisableUpdate(int cid);
 extern CGError SLSReenableUpdate(int cid);
@@ -28,12 +31,13 @@ extern CGError SLSAddActivationRegion(uint32_t cid, uint32_t wid, CFTypeRef regi
 extern CGError SLSAddTrackingRect(uint32_t cid, uint32_t wid, CGRect rect);
 extern CGError SLSClearActivationRegion(uint32_t cid, uint32_t wid);
 extern CGError SLSRemoveAllTrackingAreas(uint32_t cid, uint32_t wid);
-extern CGError SLSMoveWindow(int cid, uint32_t wid, CGPoint *point);
+extern CGError SLSMoveWindow(int cid, uint32_t wid, CGPoint* point);
 extern CGError SLSWindowSetShadowProperties(uint32_t wid, CFDictionaryRef properties);
 extern CGError SLSAddWindowToWindowOrderingGroup(int cid, uint32_t parent_wid, uint32_t child_wid, int order);
 extern CGError SLSRemoveFromOrderingGroup(int cid, uint32_t wid);
 extern CGError SLSReassociateWindowsSpacesByGeometry(int cid, CFArrayRef wids);
-extern void SLSMoveWindowsToManagedSpace(int cid, CFArrayRef window_list, uint64_t sid);
+extern CGError SLSMoveWindowsToManagedSpace(int cid, CFArrayRef window_list, uint64_t sid);
+extern CGError SLSMoveWindowWithGroup(int cid, uint32_t wid, CGPoint* point);
 
 extern void SLSCaptureWindowsContentsToRectWithOptions(uint32_t cid, uint64_t* wid, bool meh, CGRect bounds, uint32_t flags, CGImageRef* image);
 extern int SLSGetScreenRectForWindow(uint32_t cid, uint32_t wid, CGRect* out);
@@ -50,13 +54,16 @@ extern CGError SLSSetSurfaceResolution(int cid, uint32_t wid, uint32_t sid, CGFl
 extern CGError SLSFlushSurface(int cid, uint32_t wid, uint32_t surface, int param);
 extern CGError SLSSetSurfaceColorSpace(int cid, uint32_t wid, uint32_t surface, CGColorSpaceRef color_space);
 
+#define kCGSExposeFadeTagBit            (1ULL <<  1)
 #define kCGSHighQualityResamplingTagBit (1ULL <<  4)
 #define kCGSStickyTagBit                (1ULL << 11)
 #define kCGSSuperStickyTagBit           (1ULL << 45)
 
 #define W_ABOVE  1
 #define W_OUT    0
-#define W_BELOW -1
+#define W_BELOW  -1
+
+extern CFTypeRef g_transaction;
 
 struct window {
   struct window* parent;
